Hyperbolic functions
--------------------

Hyperbolic functions
....................

:func:`~mpmath.cosh`
^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.cosh(x, **kwargs)

:func:`~mpmath.sinh`
^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.sinh(x, **kwargs)

:func:`~mpmath.tanh`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.tanh(x, **kwargs)

:func:`~mpmath.sech`
^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.sech(x)

:func:`~mpmath.csch`
^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.csch(x)

:func:`~mpmath.coth`
^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.coth(x)

Inverse hyperbolic functions
............................

:func:`~mpmath.acosh`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.acosh(x, **kwargs)

:func:`~mpmath.asinh`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.asinh(x, **kwargs)

:func:`~mpmath.atanh`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.atanh(x, **kwargs)

:func:`~mpmath.asech`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.asech(x)

:func:`~mpmath.acsch`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.acsch(x)

:func:`~mpmath.acoth`
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: mpmath.acoth(x)
